Package: weightederm
Type: Package
Title: Weighted Empirical Risk Minimization for Changepoint Regression
Version: 0.1.0
Authors@R: c(
    person("Gabriel", "Arpino", role = c("aut", "cre"),
           email = "arpino.gabriel@gmail.com"))
Description: R interface to the 'weightederm' package for 'Python', which
    provides 'scikit-learn'-style estimators for offline change point
    regression (data segmentation) via weighted empirical risk minimization.
    Supports least-squares, Huber, and logistic losses with fixed or
    cross-validated numbers of change points. Wraps 'Python' via 'reticulate'.
    Arpino and Venkataramanan (2026) <doi:10.48550/arXiv.2604.11746>.
License: Apache License (>= 2.0)
URL: https://github.com/gabrielarpino/weightederm-r
BugReports: https://github.com/gabrielarpino/weightederm-r/issues
Imports: reticulate (>= 1.28)
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
SystemRequirements: Python (>= 3.9), weightederm Python package
NeedsCompilation: no
Packaged: 2026-04-21 21:45:01 UTC; gabrielarpino
Author: Gabriel Arpino [aut, cre]
Maintainer: Gabriel Arpino <arpino.gabriel@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-22 08:20:02 UTC
Built: R 4.5.2; ; 2026-04-22 09:39:42 UTC; unix
