# Generated by roxygen2: do not edit by hand

S3method(coef,werm_fit)
S3method(predict,werm_fit)
S3method(print,werm_fit)
S3method(summary,werm_fit)
export(weightederm_configure_python)
export(weightederm_examples_available)
export(werm_huber)
export(werm_huber_cv)
export(werm_least_squares)
export(werm_least_squares_cv)
export(werm_logistic)
export(werm_logistic_cv)
